==> trend_etl-1.3.1-py3-none-any.whl: trend_etl/tasks/report_discord_stats.py <==
import argparse
from typing import cast, Generator
import json

from slack_sdk import WebClient

from pyspark.dbutils import DBUtils  # type: ignore
from pyspark.sql import SparkSession, DataFrame
from trend_etl.functions.index import full_table_name
from trend_etl.transform.discord_stats import (
    total_registered_users_number,
    total_journeys_number,
    journey_conversion_number,
    total_statements_number,
    active_users_days_ago_number,
    active_audience_days_ago_number,
    retention_audience_number,
)
import trend_etl.schema.args as arguments

program = "report_discord_stats"
message_count_threshold = 4
reaction_count_threshold = 2


def get_slack_api_token(spark: SparkSession) -> str:
    dbutils = DBUtils(spark)

    token = dbutils.secrets.get(scope="slack", key="trendy")

    return token


def report_registered_users(
    guild_members: DataFrame,
):
    registered_users = total_registered_users_number(guild_members)
    message = f"{registered_users} Total Registered Users"

    return message


def report_total_statements(
    threads: DataFrame,
    messages: DataFrame,
):
    total_statements = total_statements_number(threads, messages)
    message = f"{total_statements} Total Statements"

    return message


def report_total_journeys(
    channels: DataFrame,
    journey_parent_channels: list[str],
):
    total_journeys = total_journeys_number(channels, journey_parent_channels)
    message = (
        f"{total_journeys} Journeys "
        f"(over {len(journey_parent_channels)} channel{'s' if len(journey_parent_channels) > 1 else ''})"
    )

    return message


def report_journey_conversion(
    channels: DataFrame,
    guild_members: DataFrame,
    journey_parent_channels: list[str],
):
    journeys_conversion = journey_conversion_number(
        channels, guild_members, journey_parent_channels
    )
    message = f"Journey Conversion: {journeys_conversion} users created journey(s)"

    return message


def report_active_users_stats(
    threads: DataFrame,
    messages: DataFrame,
) -> Generator[str, None, None]:
    for days_ago in (30, 60, 90):
        active_users = active_users_days_ago_number(
            threads, messages, days_ago, message_count_threshold
        )
        message = f"{active_users} active users in the last {days_ago} days"

        yield message


def report_active_audience_stats(
    threads: DataFrame,
    messages: DataFrame,
    reactions: DataFrame,
) -> Generator[str, None, None]:
    for days_ago in (30,):
        active_audience = active_audience_days_ago_number(
            threads,
            messages,
            reactions,
            days_ago,
            message_count_threshold,
            reaction_count_threshold,
        )
        message = f"{active_audience} active audience in the last {days_ago} days"

        yield message


def report_audience_retention(
    threads: DataFrame,
    messages: DataFrame,
    reactions: DataFrame,
    days_partition: int,
):
    audience_retention = retention_audience_number(
        threads, messages, reactions, days_partition
    )
    message = (
        f"{audience_retention} retained for an active audience "
        f"(in the last {days_partition} days)"
    )

    return message


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    # JSON schema [string]
    parser.add_argument(
        "--journey-channels",
        dest="journey_channels",
        required=True,
        help="A JSON list of channels (dedicated for journeys) to collect data for",
    )

    parser.add_argument(
        "--slack-channel-id",
        dest="slack_channel_id",
        required=True,
        help="The unique databricks (job) run id that runs this",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    journey_parent_channels = json.loads(args.journey_channels)

    trendy_token = get_slack_api_token(spark)
    slack_client = WebClient(token=trendy_token)

    channels_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_channels],
    )
    threads_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_threads],
    )
    messages_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_messages],
    )
    reactions_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_reactions],
    )
    members_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_members],
    )

    channels = spark.read.format("delta").table(channels_table)
    threads = spark.read.format("delta").table(threads_table)
    messages = spark.read.format("delta").table(messages_table)
    reactions = spark.read.format("delta").table(reactions_table)
    guild_members = spark.read.format("delta").table(members_table)

    message_comps = (
        [
            "Discord Daily Stats",
            report_registered_users(guild_members),
            report_total_statements(threads, messages),
            report_total_journeys(channels, journey_parent_channels),
            report_journey_conversion(channels, guild_members, journey_parent_channels),
        ]
        + [
            "\n",
            (
                "Active users are defined as creating "
                f"{message_count_threshold} or more messages "
                "within the below time periods"
            ),
        ]
        + list(report_active_users_stats(threads, messages))
        + [
            "\n",
            (
                "Active audience is active users and also "
                "includes users that have reacted"
                f"{reaction_count_threshold} or more times"
            ),
        ]
        + list(report_active_audience_stats(threads, messages, reactions))
    )

    slack_client.chat_postMessage(
        channel=args.slack_channel_id,
        text="\n".join(message_comps),
    )


if __name__ == "__main__":
    main()

==> trend_etl-1.4.14-py3-none-any.whl: trend_etl/tasks/report_discord_stats.py <==
import argparse
from typing import cast, Generator
import json

from slack_sdk import WebClient

# pylint: disable-next=import-error,no-name-in-module
from pyspark.dbutils import DBUtils  # type: ignore
from pyspark.sql import SparkSession, DataFrame
from trend_etl.functions.delta import full_table_name
from trend_etl.transform.discord_stats import (
    total_registered_users_number,
    total_journeys_number,
    journey_conversion_number,
    total_statements_number,
    active_users_days_ago_number,
    active_audience_days_ago_number,
    retention_audience_number,
)
import trend_etl.schema.args as arguments

program = "report_discord_stats"
message_count_threshold = 4
reaction_count_threshold = 2


def get_slack_api_token(spark: SparkSession) -> str:
    dbutils = DBUtils(spark)

    token = dbutils.secrets.get(scope="slack", key="trendy")

    return token


def report_registered_users(
    guild_members: DataFrame,
):
    registered_users = total_registered_users_number(guild_members)
    message = f"{registered_users} Total Registered Users"

    return message


def report_total_statements(
    threads: DataFrame,
    messages: DataFrame,
):
    total_statements = total_statements_number(threads, messages)
    message = f"{total_statements} Total Statements"

    return message


def report_total_journeys(
    channels: DataFrame,
    journey_parent_channels: list[str],
):
    total_journeys = total_journeys_number(channels, journey_parent_channels)
    message = (
        f"{total_journeys} Journeys "
        f"(over {len(journey_parent_channels)} channel{'s' if len(journey_parent_channels) > 1 else ''})"
    )

    return message


def report_journey_conversion(
    channels: DataFrame,
    guild_members: DataFrame,
    journey_parent_channels: list[str],
):
    journeys_conversion = journey_conversion_number(
        channels, guild_members, journey_parent_channels
    )
    message = f"Journey Conversion: {journeys_conversion} users created journey(s)"

    return message


def report_active_users_stats(
    threads: DataFrame,
    messages: DataFrame,
) -> Generator[str, None, None]:
    for days_ago in (30, 60, 90):
        active_users = active_users_days_ago_number(
            threads, messages, days_ago, message_count_threshold
        )
        message = f"{active_users} active users in the last {days_ago} days"

        yield message


def report_active_audience_stats(
    threads: DataFrame,
    messages: DataFrame,
    reactions: DataFrame,
) -> Generator[str, None, None]:
    for days_ago in (30,):
        active_audience = active_audience_days_ago_number(
            threads,
            messages,
            reactions,
            days_ago,
            message_count_threshold,
            reaction_count_threshold,
        )
        message = f"{active_audience} active audience in the last {days_ago} days"

        yield message


def report_audience_retention(
    threads: DataFrame,
    messages: DataFrame,
    reactions: DataFrame,
    days_partition: int,
):
    audience_retention = retention_audience_number(
        threads, messages, reactions, days_partition
    )
    message = (
        f"{audience_retention} retained for an active audience "
        f"(in the last {days_partition} days)"
    )

    return message


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unit catalog to use",
    )

    # JSON schema [string]
    parser.add_argument(
        "--journey-channels",
        dest="journey_channels",
        required=True,
        help="A JSON list of channels (dedicated for journeys) to collect data for",
    )

    parser.add_argument(
        "--slack-channel-id",
        dest="slack_channel_id",
        required=True,
        help="The unique databricks (job) run id that runs this",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    journey_parent_channels = json.loads(args.journey_channels)

    trendy_token = get_slack_api_token(spark)
    slack_client = WebClient(token=trendy_token)

    channels_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_channels],
    )
    threads_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_threads],
    )
    messages_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_messages],
    )
    reactions_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_reactions],
    )
    members_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        arguments.tables[arguments.tables_discord_members],
    )

    channels = spark.read.format("delta").table(channels_table)
    threads = spark.read.format("delta").table(threads_table)
    messages = spark.read.format("delta").table(messages_table)
    reactions = spark.read.format("delta").table(reactions_table)
    guild_members = spark.read.format("delta").table(members_table)

    message_comps = (
        [
            "Discord Daily Stats",
            report_registered_users(guild_members),
            report_total_statements(threads, messages),
            report_total_journeys(channels, journey_parent_channels),
            report_journey_conversion(channels, guild_members, journey_parent_channels),
        ]
        + [
            "\n",
            (
                "Active users are defined as creating "
                f"{message_count_threshold} or more messages "
                "within the below time periods"
            ),
        ]
        + list(report_active_users_stats(threads, messages))
        + [
            "\n",
            (
                "Active audience are active users plus "
                "users that have reacted "
                f"{reaction_count_threshold} or more times"
            ),
        ]
        + list(report_active_audience_stats(threads, messages, reactions))
    )

    slack_client.chat_postMessage(
        channel=args.slack_channel_id,
        text="\n".join(message_comps),
    )


if __name__ == "__main__":
    main()
